ComponentBlockSyntax class

Parses Jaspr components.

Inheritance

Constructors

ComponentBlockSyntax({required List<Type> importComponents})
Instantiates a Jaspr component syntax with importComponents.

Properties

hashCode int
The hash code for this object.
no setterinherited
importComponents List<Type>
List of component types to be used in Markdown.
final
pattern RegExp
Gets the regex used to identify the beginning of this block, if any.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canEndBlock(BlockParser parser) bool
inherited
canParse(BlockParser parser) bool
inherited
interruptedBy(BlockParser parser) BlockSyntax?
Returns the block which interrupts current syntax parsing if there is one, otherwise returns null.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BlockParser parser) Node
override
parseChildLines(BlockParser parser) List<Line>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited